@@ -115,7 +115,18 @@ class SecurityGroup(
         :param security_group_name: The name of the security group. For valid values, see the GroupName parameter of the CreateSecurityGroup action in the Amazon EC2 API Reference. It is not recommended to use an explicit group name. Default: If you don't specify a GroupName, AWS CloudFormation generates a unique physical ID and uses that ID for the group name.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SecurityGroup.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                vpc: aws_cdk.aws_ec2.IVpc,
+                allow_all_outbound: typing.Optional[builtins.bool] = None,
+                description: typing.Optional[builtins.str] = None,
+                disable_inline_rules: typing.Optional[builtins.bool] = None,
+                security_group_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SecurityGroupProps(
@@ -164,7 +175,16 @@ class SecurityGroupProps(aws_cdk.aws_ec2.SecurityGroupProps):
         :param security_group_name: The name of the security group. For valid values, see the GroupName parameter of the CreateSecurityGroup action in the Amazon EC2 API Reference. It is not recommended to use an explicit group name. Default: If you don't specify a GroupName, AWS CloudFormation generates a unique physical ID and uses that ID for the group name.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SecurityGroupProps.__init__)
+            def stub(
+                *,
+                vpc: aws_cdk.aws_ec2.IVpc,
+                allow_all_outbound: typing.Optional[builtins.bool] = None,
+                description: typing.Optional[builtins.str] = None,
+                disable_inline_rules: typing.Optional[builtins.bool] = None,
+                security_group_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument allow_all_outbound", value=allow_all_outbound, expected_type=type_hints["allow_all_outbound"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
